==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/RangeAllocationBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RangeAllocationBuilder extends io.fabric8.openshift.api.model.RangeAllocationFluentImpl<io.fabric8.openshift.api.model.RangeAllocationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RangeAllocation,io.fabric8.openshift.api.model.RangeAllocationBuilder>{
  public RangeAllocationBuilder() {
    this(false);
  }
  public RangeAllocationBuilder(java.lang.Boolean validationEnabled) {
    this(new RangeAllocation(), validationEnabled);
  }
  public RangeAllocationBuilder(io.fabric8.openshift.api.model.RangeAllocationFluent<?> fluent) {
    this(fluent, false);
  }
  public RangeAllocationBuilder(io.fabric8.openshift.api.model.RangeAllocationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RangeAllocation(), validationEnabled);
  }
  public RangeAllocationBuilder(io.fabric8.openshift.api.model.RangeAllocationFluent<?> fluent,io.fabric8.openshift.api.model.RangeAllocation instance) {
    this(fluent, instance, false);
  }
  public RangeAllocationBuilder(io.fabric8.openshift.api.model.RangeAllocationFluent<?> fluent,io.fabric8.openshift.api.model.RangeAllocation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withData(instance.getData()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withRange(instance.getRange()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RangeAllocationBuilder(io.fabric8.openshift.api.model.RangeAllocation instance) {
    this(instance,false);
  }
  public RangeAllocationBuilder(io.fabric8.openshift.api.model.RangeAllocation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withData(instance.getData()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRange(instance.getRange()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RangeAllocationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RangeAllocation build() {
    RangeAllocation buildable = new RangeAllocation(fluent.getApiVersion(),fluent.getData(),fluent.getKind(),fluent.getMetadata(),fluent.getRange());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RangeAllocationBuilder that = (RangeAllocationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.6.2-sources.jar: io/fabric8/openshift/api/model/RangeAllocationBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RangeAllocationBuilder extends RangeAllocationFluentImpl<RangeAllocationBuilder> implements VisitableBuilder<RangeAllocation,RangeAllocationBuilder>{
  public RangeAllocationBuilder() {
    this(false);
  }
  public RangeAllocationBuilder(Boolean validationEnabled) {
    this(new RangeAllocation(), validationEnabled);
  }
  public RangeAllocationBuilder(RangeAllocationFluent<?> fluent) {
    this(fluent, false);
  }
  public RangeAllocationBuilder(RangeAllocationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RangeAllocation(), validationEnabled);
  }
  public RangeAllocationBuilder(RangeAllocationFluent<?> fluent,RangeAllocation instance) {
    this(fluent, instance, false);
  }
  public RangeAllocationBuilder(RangeAllocationFluent<?> fluent,RangeAllocation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withData(instance.getData()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withRange(instance.getRange()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RangeAllocationBuilder(RangeAllocation instance) {
    this(instance,false);
  }
  public RangeAllocationBuilder(RangeAllocation instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withData(instance.getData()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRange(instance.getRange()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RangeAllocationFluent<?> fluent;
  Boolean validationEnabled;
  public RangeAllocation build() {
    RangeAllocation buildable = new RangeAllocation(fluent.getApiVersion(),fluent.getData(),fluent.getKind(),fluent.getMetadata(),fluent.getRange());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
